NAME = "kamangir"

ICON = "📜"

DESCRIPTION = f"{ICON} github/kamangir."

VERSION = "3.182.1"

MARQUEE = (
    "https://github.com/kamangir/assets/blob/main/abadpour/2020-11-21.jpg?raw=true"
)

REPO_NAME = NAME

ALIAS = NAME



from typing import List

from blue_options.terminal import show_usage, xtra
from abcli.help.generic import help_functions as generic_help_functions

from kamangir import ALIAS


help_functions = generic_help_functions(plugin_name=ALIAS)
